@@ -5,9 +5,11 @@ __all__ = [
     "MemoryMetricStore",
     "ApiStore",
     "CloudWatch",
+    "Slack",
 ]
 from sinai.stores.api import ApiStore
 from sinai.stores.base import MetricStore, Store
 from sinai.stores.cloudwatch import CloudWatch
 from sinai.stores.memory import MemoryMetricStore
 from sinai.stores.mongo import MongoMetricStore
+from sinai.stores.slack import Slack
